@@ -7,7 +7,7 @@ package Spreadsheet::WriteExcel::Properties;
 #
 # Used in conjunction with Spreadsheet::WriteExcel
 #
-# Copyright 2000-2009, John McNamara.
+# Copyright 2000-2010, John McNamara.
 #
 # Documentation after __END__
 #
@@ -24,7 +24,7 @@ use Time::Local 'timelocal';
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 @ISA        = qw(Exporter);
 
-$VERSION    = '2.32';
+$VERSION    = '2.33';
 
 # Set up the exports.
 my @all_functions = qw(
@@ -347,6 +347,6 @@ John McNamara jmcnamara@cpan.org
 
 =head1 COPYRIGHT
 
- MM-MMIX, John McNamara.
+ MM-MMX, John McNamara.
 
 All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as Perl itself.
